@@ -36,7 +36,7 @@ def migrate():
     doma_google_host = 'https://34.133.138.229:443/idds'  # noqa F841
 
     cm1 = ClientManager(host=atlas_host)
-    # cm1 = ClientManager(host=doma_host)
+    cm1 = ClientManager(host=doma_host)
     # reqs = cm1.get_requests(request_id=290)
     # old_request_id = 298163
     # old_request_id = 350723
@@ -45,6 +45,8 @@ def migrate():
     old_request_id = 2400
     old_request_id = 371204
     old_request_id = 372930
+    old_request_id = 2603
+    old_request_id = 2802
 
     # for old_request_id in [152]:
     # for old_request_id in [60]:    # noqa E115
@@ -54,7 +56,7 @@ def migrate():
 
         cm2 = ClientManager(host=dev_host)
         cm2 = ClientManager(host=doma_host)
-        cm2 = ClientManager(host=atlas_host)
+        # cm2 = ClientManager(host=atlas_host)
         # print(reqs)
 
         print("num requests: %s" % len(reqs))
